<?php
/**
 * The default template for displaying event content
 *
 * Used for both single and index/archive/search.
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Exit if accessed directly
}

$show_post_thumbnail = ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) ? false : true;
$post_categories   = function_exists( 'fw_get_db_customizer_option' ) ? fw_get_db_customizer_option( 'post_categories' ) : false;
$post_tags   = function_exists( 'fw_get_db_customizer_option' ) ? fw_get_db_customizer_option( 'post_tags' ) : false;

//single item layout
if ( is_singular() ) :
	//part of template for single event layout is overriden in framework-customizations/extensions/events/views/single.php
	?>

	<article id="post-<?php the_ID(); ?>" <?php post_class( 'vertical-item content-padding with_border overflow-hidden rounded' ); ?>>
		<?php aircool_post_thumbnail(); ?>
		<div class="entry-content">
			<header class="entry-header">
				<div class="item-meta content-justify">
					<div class="entry-date">
						<?php
						if ( 'post' == get_post_type() ) {
							aircool_posted_on();
						}
						?>
					</div><!-- .entry-date -->
					<!-- .item cats -->
					<?php if ( $post_categories == 'yes' ) : ?>
						<?php if ( in_array( 'category', get_object_taxonomies( get_post_type() ) ) && aircool_categorized_blog() ) : ?>
							<span
								class="categories-links color1"><?php echo get_the_category_list( _x( ' ', 'Used between list items, there is a space after the comma.', 'aircool' ) ); ?></span>
						<?php endif; ?>
					<?php endif; ?>
					<!-- .item cats -->
				</div>
			</header><!-- .entry-header -->

			<?php
			the_content( esc_html__( 'More...', 'aircool' ) );
			?>

			<!-- .item tags -->
			<?php if ( $post_tags == 'yes' ) : ?>
				<?php the_tags( '<footer class="entry-meta"><span class="tag-links color1">', ' ', '</span></footer>' ); ?>
			<?php endif; ?>
			<!-- .item tags -->
			<?php
			wp_link_pages( array(
				'before'      => '<div class="page-links topmargin_30"><span class="page-links-title">' . esc_html__( 'Pages:', 'aircool' ) . '</span>',
				'after'       => '</div>',
				'link_before' => '<span>',
				'link_after'  => '</span>',
			) );
			?>
		</div><!-- .entry-content -->

	</article><!-- #post-## -->

	<?php
//eof single page layout
//blog feed layout
else:
	$options = ( function_exists( 'fw_get_db_post_option' ) ) ? fw_get_db_post_option( $post->ID, fw()->extensions->get( 'events' )->get_event_option_id() ) : false;

	//layout for events in feed is always two columns if it has a featured image
	$small_layout = ( ! $show_post_thumbnail ) ? false : true;
	if ( $small_layout ) : //additional markup for small layout post
		?>

		<article id="post-<?php the_ID(); ?>" <?php post_class( 'vertical-item content-padding with_border overflow-hidden rounded' ); ?>>
		<div class="side-item content-padding big-padding with_border overflow-hidden rounded">
		<div class="row">
		<?php aircool_post_thumbnail( $small_layout ); ?>
		<div class="col-md-6">

	<?php else : //standard layout markup ?>
		<article id="post-<?php the_ID(); ?>" <?php post_class( 'vertical-item content-padding with_border overflow-hidden rounded' ); ?>>
		<?php
		aircool_post_thumbnail();
	endif; //small_format check
	?>
	<div class="item-content">

		<header class="entry-header">
			<div class="item-meta content-justify">
				<?php
				if ( 'post' == get_post_type() ) {
					aircool_posted_on();
				}
				?>
				<!-- .item cats -->
				<?php if ( $post_categories == 'yes' ) : ?>
					<?php if ( in_array( 'category', get_object_taxonomies( get_post_type() ) ) && aircool_categorized_blog() ) : ?>
						<div
							class="categories-links color1"><?php echo get_the_category_list( _x( ' ', 'Used between list items, there is a space after the comma.', 'aircool' ) ); ?></div>
					<?php endif; ?>
				<?php endif; ?>
				<!-- .item cats -->
			</div>
			<?php
			the_title( '<h4 class="entry-title"><a href="' . esc_url( get_permalink() ) . '" rel="bookmark">', '</a></h4>' );
			?>
		</header><!-- .entry-header -->

		<?php if ( is_search() ) : ?>
			<div class="entry-summary">
				<?php the_excerpt(); ?>
			</div><!-- .entry-summary -->
		<?php else : ?>
			<div class="entry-content">
				<?php
				//hidding "more link" in content
				the_content( esc_html__( 'More...', 'aircool' ) );

				wp_link_pages( array(
					'before'      => '<div class="page-links topmargin_30"><span class="page-links-title">' . esc_html__( 'Pages:', 'aircool' ) . '</span>',
					'after'       => '</div>',
					'link_before' => '<span>',
					'link_after'  => '</span>',
				) );
				?>
			</div><!-- .entry-content -->
		<?php endif; //is_search ?>
	</div><!-- eof .item-content -->
	<?php if ( $small_layout ) : //additional markup for small format post  ?>
	</div><!-- eof .col-md-6 -->
	</div><!-- eof .row -->
	</div><!-- eof .side-item -->
<?php endif; //small_format 
	?>
	</article><!-- #post-## -->

<?php endif;  //is singular ?>